==> haskell-hsopenssl-x509-system-0.1.0.4-56-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HsOpenSSL-x509-system
version:              0.1.0.4
visibility:           public
id:                   HsOpenSSL-x509-system-0.1.0.4-J1Xzk96AvfBFuKl7f7BtRp
key:                  HsOpenSSL-x509-system-0.1.0.4-J1Xzk96AvfBFuKl7f7BtRp
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/HsOpenSSL-x509-system
synopsis:             Use the system'\''s native CA certificate store with HsOpenSSL
description:
    A cross-platform library that tries to find a (reasonable) CA certificate
    bundle that can be used with @HsOpenSSL@ to verify the certificates of
    remote peers.

    This package is for @HsOpenSSL@ what @x509-system@ is for the @tls@ package.
    Additionally, it borrows some ideas from @x509-system@.

category:             System, Filesystem
abi:                  7825441304a7575f5c3f505dff146129
exposed:              True
exposed-modules:      OpenSSL.X509.SystemStore
hidden-modules:       OpenSSL.X509.SystemStore.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/HsOpenSSL-x509-system-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsopenssl-x509-system
hs-libraries:         HSHsOpenSSL-x509-system-0.1.0.4-J1Xzk96AvfBFuKl7f7BtRp
depends:
    HsOpenSSL-0.11.7.6-2EI6PO3Kfl51FoShESk8Fp base-4.16.4.0
    bytestring-0.11.4.0 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-hsopenssl-x509-system/html/HsOpenSSL-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-hsopenssl-x509-system/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsopenssl-x509-system-0.1.0.4-87.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hsopenssl-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsOpenSSL-x509-system
version:              0.1.0.4
visibility:           public
id:                   HsOpenSSL-x509-system-0.1.0.4-C2nVog7ESt79LO87hHowiQ
key:                  HsOpenSSL-x509-system-0.1.0.4-C2nVog7ESt79LO87hHowiQ
license:              BSD-3-Clause
maintainer:           Marios Titas <rednebΑΤgmxDΟΤcom>
author:               Marios Titas <rednebΑΤgmxDΟΤcom>
homepage:             https://github.com/redneb/HsOpenSSL-x509-system
synopsis:             Use the system'\''s native CA certificate store with HsOpenSSL
description:
    A cross-platform library that tries to find a (reasonable) CA certificate
    bundle that can be used with @HsOpenSSL@ to verify the certificates of
    remote peers.

    This package is for @HsOpenSSL@ what @x509-system@ is for the @tls@ package.
    Additionally, it borrows some ideas from @x509-system@.

category:             System, Filesystem
abi:                  f8615b28e609c58128a5245aaf81c294
exposed:              True
exposed-modules:      OpenSSL.X509.SystemStore
hidden-modules:       OpenSSL.X509.SystemStore.Unix
import-dirs:          /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/HsOpenSSL-x509-system-0.1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsopenssl-x509-system
hs-libraries:         HSHsOpenSSL-x509-system-0.1.0.4-C2nVog7ESt79LO87hHowiQ
depends:
    HsOpenSSL-0.11.7.9-334NuEYN9GGBbdLoXuU7H9 base-4.17.2.1
    bytestring-0.11.5.3 unix-2.7.3

haddock-interfaces:
    /usr/share/doc/haskell-hsopenssl-x509-system/html/HsOpenSSL-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-hsopenssl-x509-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
